\name{Multistate-package}
\alias{Multistate-package}
\alias{Multistate}
\docType{package}
\title{
Multistate models
}
\description{
Medical researchers are often interested in investigating the relationship between explicative variables and times-to-events such as disease progression or death. Multistate models allows multiple times-to-event to be studied simultaneously. Time-inhomogeneous Markov models consist of modelling the probabilities of transitions according to the chronological times (times since the baseline of the study). Semi-Markov (SM) models consist of modelling the probabilities of transitions according to the times spent in states. These SM models are becoming increasingly popular to deal with the complex evolution of chronic diseases. In this package, we propose functions implementing usual 3-state and 4-state multistate models (SM models and time-inhomogeneous Markov models). We also propose to take into account the mortality of the general population (relative survival approach).   

\tabular{rl}{
Additive relative survival \tab The excess mortality related to a disease is estimated by subtracting the \cr
 \eqn{  } \tab expected mortality rates from general population life tables to the observed \cr
 \eqn{  } \tab mortality rates.\cr
}                        

The methods proposed are limited to parametric models. The 3-state (illness-death) models model include one initial state (X=1), one transient state (X=2), and an absorbing state (X=3). The possible transitions are: 1->2, 1->3 and 2->3.  The 4-state models include one initial state (X=1), one transient state (X=2), and two competing and absorbing states (X=3 and X=4). The possible transitions are: 1->2, 1->3, 1->4, 2->3 and 2->4.

}

\details{
\tabular{ll}{
Package: \tab Multistate\cr
Type: \tab Package\cr
Version: \tab 0.2\cr
Date: \tab 2015-03-03\cr
License: \tab GPL (>=2)\cr
LazyLoad: \tab yes\cr
}


\tabular{rl}{
m3 \tab computes a 3-state time-inhomogeneous Markov model \cr
m4 \tab computes a 4-state time-inhomogeneous Markov model \cr
sm3 \tab computes a 3-state semi-Markov model \cr
sm4 \tab computes a 4-state semi-Markov model \cr
mrs3 \tab computes a 3-state additive relative survival time-inhomogeneous Markov model \cr
mrs4 \tab computes a 4-state additive relative survival time-inhomogeneous Markov model \cr
smrs3 \tab computes a 3-state additive relative survival semi-Markov model \cr
smrs4 \tab computes a 4-state additive relative survival semi-Markov model \cr
}
}
\author{
Yohann Foucher <Yohann.Foucher@univ-nantes.fr>

and Florence Gillaizeau <Florence.Gillaizeau@univ-nantes.fr>
}
\references{
Gillaizeau F, Dantan E, Giral M, Foucher Y. A multistate additive relative survival semi-Markov model. Manuscript submitted. 2015.
}

\keyword{ Markov }
\keyword{ semi-Markov }
\keyword{ multistate }
\keyword{ relative survival }

\seealso{
URL: http://www.divat.fr/
}
